@@ -1,8 +1,8 @@
 # test BF on lm object
 
 lm1 <-  lm(wt ~ disp + drat + hp, mtcars)
-BF1a <- BF(lm1,BF.type = 2)
-BF1aa <- BF(lm1,BF.type = 2,prior.hyp.explo = 1:3)
+BF1a <- BF(lm1,BF.type = "AFBF",prior.hyp.explo = c(1,1,1))
+BF1aa <- BF(lm1,BF.type = "AFBF",prior.hyp.explo = 1:3)
 #check exploratory test
 PHPexplo <- matrix(
   c(0.065,  0.003,  0.931,
@@ -23,7 +23,7 @@ test_that("BF.lm exploratory hypotheses correctly evaluated", {
   )
 })
 
-BF1b <- BF(lm1,BF.type = 1)
+BF1b <- BF(lm1,BF.type = "FBF",prior.hyp.explo=c(1,1,1))
 PHPexplo <- matrix(
   c(0.107,  0.006,  0.887,
     0.002,  0.000,  0.998,
@@ -35,37 +35,37 @@ test_that("BF.lm exploratory hypotheses correctly evaluated", {
   )})
 
 
-BF2 <- BF(lm1,hypothesis="disp=drat=0;disp>drat>0;disp>drat=0")
+BF2 <- BF(lm1,hypothesis="disp=drat=0;disp>drat>0;disp>drat=0",BF.type="AFBF")
 test_that("BF.lm multiple confirmatory hypotheses correctly evaluated", {
   expect_equivalent(
     round(BF2$PHP_confirmatory,5),c(0.000,0.533,0.402,0.064), tolerance = .01
 )})
 
-BF2 <- BF(lm1,hypothesis="disp=drat=0;disp>drat>0;disp>drat=0",complement=FALSE)
+BF2 <- BF(lm1,hypothesis="disp=drat=0;disp>drat>0;disp>drat=0",complement=FALSE,BF.type="AFBF")
 test_that("BF.lm multiple confirmatory hypotheses correctly evaluated", {
   expect_equivalent(
     round(BF2$PHP_confirmatory,5),c(0.00000,0.57003,0.42997)
   )})
 
-BF3 <- BF(lm1,hypothesis="disp=hp=0")
+BF3 <- BF(lm1,hypothesis="disp=hp=0",BF.type="AFBF")
 test_that("BF.lm one equality hypothesis correctly evaluated", {
   expect_equivalent(
     round(BF3$PHP_confirmatory,5),c(0.00003,0.99997)
   )})
 
-BF4 <- BF(lm1,hypothesis="drat<hp<disp")
+BF4 <- BF(lm1,hypothesis="drat<hp<disp",BF.type="AFBF")
 test_that("BF.lm one order hypothesis correctly evaluated", {
   expect_equivalent(
     round(BF4$PHP_confirmatory,5),c(0.96872,0.03128)
   )})
 
-BF5 <- BF(lm1,hypothesis="drat<hp=disp")
+BF5 <- BF(lm1,hypothesis="drat<hp=disp",BF.type="FBF")
 test_that("BF.lm one equal/order hypothesis correctly evaluated", {
   expect_equivalent(
-    round(BF5$PHP_confirmatory,5),c(0.47961,0.52039)
+    round(BF5$PHP_confirmatory,5),c(0.44049,0.55951)
   )})
 
-BF5b <- BF(lm1,hypothesis="drat<hp=disp",BF.type = 1)
+BF5b <- BF(lm1,hypothesis="drat<hp=disp",BF.type = "FBF")
 test_that("BF.lm one equal/order hypothesis correctly evaluated", {
   expect_equivalent(
     round(BF5b$PHP_confirmatory,5),c(0.44049,0.55951)
